# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ComputerDragParams"]


class ComputerDragParams(TypedDict, total=False):
    tab_id: str

    x1: float

    x2: float

    y1: float

    y2: float
